<p align="center">
  <p align="center"><img width="238" height="135" src="https://pysimplegui.net/images/logos/psglogofull.svg"><p>

  <h2 align="center">psgdemos</h2>
  <h2 align="center">A PySimpleGUI Application</h2>
</p>

PySimpleGUI Demo Programs

Demonstrate PySimpleGUI features. Are you trying to figure out a
specific feature of PySimpleGUI? There's a demo for that! The Demo
Browser let's you search through hundreds of demo programs to find
ones that demonstrates the features you need.





<p align="center"><img width="679" height="436" src="screenshot.png"><p>







## Features

* Hundreds of programs to demonstrate any feature.
* Run demos with a single click.
* Browse demo names and search demo source code.
* Integrates with your favorite editor.
* Advanced features for advanced users.


## Installation

### Using PIP with PyPI

The latest official release of PySimpleGUI products can be found on PyPI.  To pip install the demo applications from PyPI, use this command

#### If you use the command `python` on your computer to invoke Python (Windows):

`python -m pip install --upgrade psgdemos`

#### If you use the command `python3` on your computer to invoke Python (Linux, Mac):

`python3 -m pip install --upgrade psgdemos`

### Using PIP with GitHub

You can also pip install the PySimpleGUI Applications that are in the PySimpleGUI GitHub account.  The GitHub versions have bug fixes and new programs/features that have not yet been released to PyPI. To directly pip install from that repo:

#### If you use the command `python` on your computer to invoke Python (Windows):

```bash
python -m pip install --upgrade https://github.com/PySimpleGUI/psgdemos/zipball/main
```

#### If you use the command `python3` on your computer to invoke Python (Linux, Mac):

```bash
python3 -m pip install --upgrade https://github.com/PySimpleGUI/psgdemos/zipball/main
```

## Usage

Once installed, launch psgdemos by typing the following in your command line:

`psgdemos`

## Create a Windows 1-Click Shortcut

psgdemos is your first stop when implementing any new feature for your
application. To keep psgdemos at your fingertips, on Windows, you can
create a shortcut that keeps psgdemos as close as a single click. Use
the [`psgshortcut` application](https://pypi.org/project/psgshortcut/)
app to make such shortcuts. You can then add the shortcut to your
desktop or taskbar and launch psgdemos with a single click!

To do this, follow these steps:

1. `pip install psgshortcut`
1. Open a command window (We promise, it's the last time you'll need the command line for psgdemos)
2. Type `where psgdemos`
3. Copy the resulting line into psgshortcut first input
4. Run psgdemos by typing `psgdemos` in your command window
5. Right click and choose "File Location"
6. Copy the file location results, but change the extension from .py to .ico and paste into the Icon file input of the shortcut maker
7. Click "Create Shortcut"

These steps create a shortcut in the same folder as the target file. You can now move this shortcut file to any place you want (like to your desktop). Double-click the shortcut and your program will launch.

## License & Copyright

Copyright 2023-2024 PySimpleSoft, Inc. and/or its licensors.

This is a free-to-use "Utility" and is licensed under the
PySimpleGUI License Agreement, a copy of which is included in the
license.txt file and also available at https://pysimplegui.com/eula.

Please see Section 1.2 of the license regarding the use of this Utility,
and see https://pysimplegui.com/faq for any questions.


## Contributing

We are happy to receive issues describing bug reports and feature
requests! If your bug report relates to a security vulnerability,
please do not file a public issue, and please instead reach out to us
at issues@PySimpleGUI.com.

We do not accept (and do not wish to receive) contributions of
user-created or third-party code, including patches, pull requests, or
code snippets incorporated into submitted issues. Please do not send
us any such code! Bug reports and feature requests should not include
any source code.

If you nonetheless submit any user-created or third-party code to us,
(1) you assign to us all rights and title in or relating to the code;
and (2) to the extent any such assignment is not fully effective, you
hereby grant to us a royalty-free, perpetual, irrevocable, worldwide,
unlimited, sublicensable, transferrable license under all intellectual
property rights embodied therein or relating thereto, to exploit the
code in any manner we choose, including to incorporate the code into
PySimpleGUI and to redistribute it under any terms at our discretion.
